# polars-io

`polars-io` is an **internal sub-crate** of the [Polars](https://crates.io/crates/polars) library,
that provides IO functionality for the Polars dataframe library.

**Important Note**: This crate is **not intended for external usage**. Please refer to the main
[Polars crate](https://crates.io/crates/polars) for intended usage.
